Expression type for CSS calc() expressions in property values
This module implements mathematical expressions that can be used in CSS calc() functions, supporting mixed units, nested expressions, and basic arithmetic.
Structs
- Eval
Context - Context for evaluating expressions
Enums
- Expression
- Mathematical expression for CSS calc() values